@@ -40,6 +40,10 @@
 #include <io.h> /* For _read() */
 #endif
 
+enum {
+  JSON_ERR_MALFORMED_SURROGATE_PAIR = G_TOKEN_LAST + 1,
+};
+
 struct _JsonScannerConfig
 {
   /* Character sets
@@ -81,41 +85,42 @@ struct _JsonScannerConfig
 
 static JsonScannerConfig json_scanner_config_template =
 {
-  ( " \t\r\n" )		/* cset_skip_characters */,
-  (
-   "_"
-   G_CSET_a_2_z
-   G_CSET_A_2_Z
-  )			/* cset_identifier_first */,
-  (
-   G_CSET_DIGITS
-   "-_"
-   G_CSET_a_2_z
-   G_CSET_A_2_Z
-  )			/* cset_identifier_nth */,
-  ( "//\n" )		/* cpair_comment_single */,
-  TRUE			/* case_sensitive */,
-  TRUE			/* skip_comment_multi */,
-  TRUE			/* skip_comment_single */,
-  FALSE			/* scan_comment_multi */,
-  TRUE			/* scan_identifier */,
-  TRUE			/* scan_identifier_1char */,
-  FALSE			/* scan_identifier_NULL */,
-  TRUE			/* scan_symbols */,
-  TRUE			/* scan_binary */,
-  TRUE			/* scan_octal */,
-  TRUE			/* scan_float */,
-  TRUE			/* scan_hex */,
-  TRUE			/* scan_hex_dollar */,
-  TRUE			/* scan_string_sq */,
-  TRUE			/* scan_string_dq */,
-  TRUE			/* numbers_2_int */,
-  FALSE			/* int_2_float */,
-  FALSE			/* identifier_2_string */,
-  TRUE			/* char_2_token */,
-  TRUE			/* symbol_2_token */,
-  FALSE			/* scope_0_fallback */,
-  TRUE                  /* store_int64 */
+  .cset_skip_characters = ( " \t\r\n" ),
+  .cset_identifier_first = (
+    "_"
+    G_CSET_a_2_z
+    G_CSET_A_2_Z
+  ),
+  .cset_identifier_nth = (
+    G_CSET_DIGITS
+    "-_"
+    G_CSET_a_2_z
+    G_CSET_A_2_Z
+  ),
+  .cpair_comment_single = ( "//\n" ),
+  .case_sensitive = TRUE,
+  .skip_comment_multi = TRUE,
+  .skip_comment_single = TRUE,
+  .scan_comment_multi = FALSE,
+  .scan_identifier = TRUE,
+  .scan_identifier_1char = TRUE,
+  .scan_identifier_NULL = FALSE,
+  .scan_symbols = TRUE,
+  .scan_binary = TRUE,
+  .scan_octal = TRUE,
+  .scan_float = TRUE,
+  .scan_hex = TRUE,
+  .scan_hex_dollar = TRUE,
+  .scan_string_sq = TRUE,
+  .scan_string_dq = TRUE,
+  .numbers_2_int = TRUE,
+  .int_2_float = FALSE,
+  .identifier_2_string = FALSE,
+  .char_2_token = TRUE,
+  .symbol_2_token = TRUE,
+  .scope_0_fallback = FALSE,
+  .store_int64 = TRUE,
+  .padding_dummy = 0,
 };
 
 /* --- defines --- */
@@ -278,8 +283,8 @@ json_scanner_free_value (GTokenType  *token_p,
 
 static void
 json_scanner_destroy_symbol_table_entry (gpointer _key,
-                                         gpointer _value,
-                                         gpointer _data)
+                                         gpointer _value G_GNUC_UNUSED,
+                                         gpointer _data G_GNUC_UNUSED)
 {
   JsonScannerKey *key = _key;
   
@@ -681,7 +686,11 @@ json_scanner_unexp_token (JsonScanner *scanner,
 	case G_ERR_DIGIT_RADIX:
 	  g_snprintf (token_string, token_string_len, "scanner: digit is beyond radix");
 	  break;
-	  
+
+	case JSON_ERR_MALFORMED_SURROGATE_PAIR:
+	  g_snprintf (token_string, token_string_len, "scanner: malformed surrogate pair");
+	  break;
+
 	case G_ERR_UNKNOWN:
 	default:
 	  g_snprintf (token_string, token_string_len, "scanner: unknown error");
@@ -1066,7 +1075,7 @@ json_scanner_get_token_ll (JsonScanner *scanner,
 	  gstring = g_string_new (NULL);
 	  while ((ch = json_scanner_get_char (scanner, line_p, position_p)) != 0)
 	    {
-	      if (ch == '"')
+	      if (ch == '"' || token == G_TOKEN_ERROR)
 		{
 		  in_string_dq = FALSE;
 		  break;
@@ -1130,8 +1139,20 @@ json_scanner_get_token_ll (JsonScanner *scanner,
                                       units[0] = ucs;
                                       units[1] = json_scanner_get_unichar (scanner, line_p, position_p);
 
-                                      ucs = decode_utf16_surrogate_pair (units);
-                                      g_assert (g_unichar_validate (ucs));
+                                      if (0xdc00 <= units[1] && units[1] <= 0xdfff &&
+                                          0xd800 <= units[0] && units[0] <= 0xdbff)
+                                        {
+                                          ucs = decode_utf16_surrogate_pair (units);
+                                          g_assert (g_unichar_validate (ucs));
+                                        }
+                                      else
+                                        {
+                                          token = G_TOKEN_ERROR;
+                                          value.v_error = JSON_ERR_MALFORMED_SURROGATE_PAIR;
+                                          gstring = NULL;
+                                          break;
+                                        }
+
                                     }
                                 }
 
