@@ -84,7 +84,7 @@ test_empty_array (void)
   g_assert_cmpint (len, ==, strlen (empty_array));
   g_assert_cmpstr (data, ==, empty_array);
 
-  g_assert (json_generator_get_pretty (gen) == FALSE);
+  g_assert_false (json_generator_get_pretty (gen));
   g_assert_cmpint (json_generator_get_indent (gen), ==, 0);
   g_assert_cmpint (json_generator_get_indent_char (gen), ==, ' ');
 
@@ -141,10 +141,9 @@ test_simple_array (void)
   g_object_set (generator, "pretty", FALSE, NULL);
   data = json_generator_to_data (generator, &len);
 
-  if (g_test_verbose ())
-    g_print ("checking simple array `%s' (expected: %s)\n",
-             data,
-             simple_array);
+  g_test_message ("checking simple array '%s' (expected: '%s')",
+                  data,
+                  simple_array);
 
   g_assert_cmpint (len, ==, strlen (simple_array));
   g_assert_cmpstr (data, ==, simple_array);
@@ -218,10 +217,9 @@ test_simple_object (void)
   g_object_set (generator, "pretty", FALSE, NULL);
   data = json_generator_to_data (generator, &len);
 
-  if (g_test_verbose ())
-    g_print ("checking simple object `%s' (expected: %s)\n",
-             data,
-             simple_object);
+  g_test_message ("checking simple object '%s' (expected: '%s')",
+                  data,
+                  simple_object);
 
   g_assert_cmpint (len, ==, strlen (simple_object));
   g_assert_cmpstr (data, ==, simple_object);
@@ -278,10 +276,9 @@ test_nested_object (void)
   g_object_set (generator, "pretty", FALSE, NULL);
   data = json_generator_to_data (generator, &len);
 
-  if (g_test_verbose ())
-    g_print ("checking nested object `%s' (expected: %s)\n",
-             data,
-             nested_object);
+  g_test_message ("checking nested object '%s' (expected: '%s')",
+                  data,
+                  nested_object);
 
   g_assert_cmpint (len, ==, strlen (nested_object));
   g_assert_cmpstr (data, ==, nested_object);
@@ -297,7 +294,6 @@ test_decimal_separator (void)
   JsonNode *node = json_node_new (JSON_NODE_VALUE);
   JsonGenerator *generator = json_generator_new ();
   gchar *old_locale;
-  gint i;
 
   json_node_set_double (node, 3.14);
 
@@ -305,7 +301,7 @@ test_decimal_separator (void)
 
   old_locale = setlocale (LC_NUMERIC, NULL);
 
-  for (i = 0; i < G_N_ELEMENTS (decimal_separator); i++)
+  for (guint i = 0; i < G_N_ELEMENTS (decimal_separator); i++)
     {
       gchar *str, *expected;
 
@@ -313,18 +309,17 @@ test_decimal_separator (void)
 
       str = json_generator_to_data (generator, NULL);
 
-      if (g_test_verbose ())
-        g_print ("%s: value: %.2f - string: '%s'\n",
-                 G_STRFUNC,
-                 json_node_get_double (node),
-                 str);
+      g_test_message ("%s: value: '%.2f' - string: '%s'",
+                      G_STRFUNC,
+                      json_node_get_double (node),
+                      str);
 
-      g_assert (str != NULL);
+      g_assert_nonnull (str);
       expected = strstr (str, decimal_separator[i].sep);
       if (decimal_separator[i].matches)
-        g_assert (expected != NULL);
+        g_assert_nonnull (expected);
       else
-        g_assert (expected == NULL);
+        g_assert_null (expected);
 
       g_free (str);
    }
@@ -355,6 +350,33 @@ test_double_stays_double (void)
   json_node_free (node);
 }
 
+static void
+test_double_valid (void)
+{
+  gchar *str;
+  JsonNode *node = json_node_new (JSON_NODE_VALUE);
+  JsonGenerator *generator = json_generator_new ();
+
+  json_node_set_double (node, 1e-8);
+  json_generator_set_root (generator, node);
+
+  str = json_generator_to_data (generator, NULL);
+  g_test_message ("%s: value: '%.2f' - string: '%s'",
+                G_STRFUNC,
+                json_node_get_double (node),
+                str);
+
+  /* should be valid double
+   * in particular; no trailing .0 for exponential notation */
+  gchar *end = NULL;
+  g_ascii_strtod(str, &end);
+  g_assert_cmpint (0, ==, *end);
+
+  g_free (str);
+  g_object_unref (generator);
+  json_node_free (node);
+}
+
 
 static void
 test_pretty (void)
@@ -373,10 +395,10 @@ test_pretty (void)
       char *data;
       gsize len;
 
-      g_assert (json_parser_load_from_data (parser, pretty_examples[i], -1, NULL));
+      g_assert_true (json_parser_load_from_data (parser, pretty_examples[i], -1, NULL));
 
       root = json_parser_get_root (parser);
-      g_assert (root != NULL);
+      g_assert_nonnull (root);
 
       json_generator_set_root (generator, root);
 
@@ -434,10 +456,6 @@ int
 main (int   argc,
       char *argv[])
 {
-  gchar *escaped;
-  gchar *name;
-  gint i;
-
   g_test_init (&argc, &argv, NULL);
 
   g_test_add_func ("/generator/empty-array", test_empty_array);
@@ -448,12 +466,13 @@ main (int   argc,
   g_test_add_func ("/generator/nested-object", test_nested_object);
   g_test_add_func ("/generator/decimal-separator", test_decimal_separator);
   g_test_add_func ("/generator/double-stays-double", test_double_stays_double);
+  g_test_add_func ("/generator/double-valid", test_double_valid);
   g_test_add_func ("/generator/pretty", test_pretty);
 
-  for (i = 0; i < G_N_ELEMENTS (string_fixtures); i++)
+  for (guint i = 0; i < G_N_ELEMENTS (string_fixtures); i++)
     {
-      escaped = g_strescape (string_fixtures[i].str, NULL);
-      name = g_strdup_printf ("/generator/string/%s", escaped);
+      char *escaped = g_strescape (string_fixtures[i].str, NULL);
+      char *name = g_strdup_printf ("/generator/string/%s", escaped);
       g_test_add_data_func (name, string_fixtures + i, test_string_encode);
       g_free (escaped);
       g_free (name);
