@@ -98,72 +98,84 @@ static const struct {
     "$.store.book[0].title",
     "[\"Sayings of the Century\"]",
     TRUE,
+    0,
   },
   {
     "Title of the first book in the store, using array notation.",
     "$['store']['book'][0]['title']",
     "[\"Sayings of the Century\"]",
     TRUE,
+    0,
   },
   {
     "All the authors from the every book.",
     "$.store.book[*].author",
     "[\"Nigel Rees\",\"Evelyn Waugh\",\"Herman Melville\",\"J. R. R. Tolkien\"]",
     TRUE,
+    0,
   },
   {
     "All the authors.",
     "$..author",
     "[\"Nigel Rees\",\"Evelyn Waugh\",\"Herman Melville\",\"J. R. R. Tolkien\"]",
     TRUE,
+    0,
   },
   {
     "Everything inside the store.",
     "$.store.*",
     NULL,
     TRUE,
+    0,
   },
   {
     "All the prices in the store.",
     "$.store..price",
     "[\"8.95\",\"12.99\",\"8.99\",\"22.99\",\"19.95\"]",
     TRUE,
+    0,
   },
   {
     "The third book.",
     "$..book[2]",
     "[{\"category\":\"fiction\",\"author\":\"Herman Melville\",\"title\":\"Moby Dick\",\"isbn\":\"0-553-21311-3\",\"price\":\"8.99\"}]",
     TRUE,
+    0,
   },
   {
     "The last book.",
     "$..book[-1:]",
     "[{\"category\":\"fiction\",\"author\":\"J. R. R. Tolkien\",\"title\":\"The Lord of the Rings\",\"isbn\":\"0-395-19395-8\",\"price\":\"22.99\"}]",
     TRUE,
+    0,
   },
   {
     "The first two books.",
     "$..book[0,1]",
     "[{\"category\":\"reference\",\"author\":\"Nigel Rees\",\"title\":\"Sayings of the Century\",\"price\":\"8.95\"},{\"category\":\"fiction\",\"author\":\"Evelyn Waugh\",\"title\":\"Sword of Honour\",\"price\":\"12.99\"}]",
     TRUE,
+    0,
   },
   {
     "The first two books, using a slice.",
     "$..book[:2]",
     "[{\"category\":\"reference\",\"author\":\"Nigel Rees\",\"title\":\"Sayings of the Century\",\"price\":\"8.95\"},{\"category\":\"fiction\",\"author\":\"Evelyn Waugh\",\"title\":\"Sword of Honour\",\"price\":\"12.99\"}]",
     TRUE,
+    0,
   },
   {
     "All the books.",
     "$['store']['book'][*]",
     "[{\"category\":\"reference\",\"author\":\"Nigel Rees\",\"title\":\"Sayings of the Century\",\"price\":\"8.95\"},{\"category\":\"fiction\",\"author\":\"Evelyn Waugh\",\"title\":\"Sword of Honour\",\"price\":\"12.99\"},{\"category\":\"fiction\",\"author\":\"Herman Melville\",\"title\":\"Moby Dick\",\"isbn\":\"0-553-21311-3\",\"price\":\"8.99\"},{\"category\":\"fiction\",\"author\":\"J. R. R. Tolkien\",\"title\":\"The Lord of the Rings\",\"isbn\":\"0-395-19395-8\",\"price\":\"22.99\"}]",
     TRUE,
+    0,
   },
   {
     "All the members of the bicycle object.",
     "$.store.bicycle.*",
     "[\"red\",\"19.95\"]",
     TRUE,
+    0,
   },
   {
     "The root node.",
@@ -174,7 +186,8 @@ static const struct {
                            "{\"category\":\"fiction\",\"author\":\"J. R. R. Tolkien\",\"title\":\"The Lord of the Rings\",\"isbn\":\"0-395-19395-8\",\"price\":\"22.99\"}],"
                  "\"bicycle\":{\"color\":\"red\",\"price\":\"19.95\"}}}]",
     TRUE,
-  }
+    0,
+  },
 };
 
 static void
@@ -187,10 +200,9 @@ path_expressions_valid (gconstpointer data)
   JsonPath *path = json_path_new ();
   GError *error = NULL;
 
-  if (g_test_verbose ())
-    g_print ("* %s ('%s')\n", desc, expr);
+  g_test_message ("* %s ('%s')", desc, expr);
 
-  g_assert (json_path_compile (path, expr, &error));
+  g_assert_true (json_path_compile (path, expr, &error));
   g_assert_no_error (error);
 
   g_object_unref (path);
@@ -207,12 +219,10 @@ path_expressions_invalid (gconstpointer data)
   JsonPath *path = json_path_new ();
   GError *error = NULL;
 
-  if (g_test_verbose ())
-    g_print ("* %s ('%s')\n", desc, expr);
+  g_test_message ("* %s ('%s')", desc, expr);
 
-
-  g_assert (!json_path_compile (path, expr, &error));
-  g_assert_error (error, JSON_PATH_ERROR, code);
+  g_assert_false (json_path_compile (path, expr, &error));
+  g_assert_error (error, JSON_PATH_ERROR, (int) code);
 
   g_object_unref (path);
   g_clear_error (&error);
@@ -236,23 +246,20 @@ path_match (gconstpointer data)
   json_parser_load_from_data (parser, test_json, -1, NULL);
   root = json_parser_get_root (parser);
 
-  g_assert (json_path_compile (path, expr, NULL));
+  g_assert_true (json_path_compile (path, expr, NULL));
 
   matches = json_path_match (path, root);
-  g_assert (JSON_NODE_HOLDS_ARRAY (matches));
+  g_assert_true (JSON_NODE_HOLDS_ARRAY (matches));
 
   json_generator_set_root (gen, matches);
   str = json_generator_to_data (gen, NULL);
 
-  if (g_test_verbose ())
-    {
-      g_print ("* %s ('%s') =>\n"
-               "- result:   %s\n"
-               "- expected: %s\n",
-               desc, expr,
-               str,
-               res);
-    }
+  g_test_message ("* %s ('%s') =>\n"
+                  "- result:   %s\n"
+                  "- expected: %s",
+                  desc, expr,
+                  str,
+                  res);
 
   g_assert_cmpstr (str, ==, res);
 
@@ -268,7 +275,7 @@ int
 main (int   argc,
       char *argv[])
 {
-  int i, j;
+  guint i, j;
 
   g_test_init (&argc, &argv, NULL);
   g_test_bug_base ("http://bugzilla.gnome.org/show_bug.cgi?id=");
